@@ -1,4 +1,6 @@
 from everywhereml.code_generators.jinja.filters.c_shape import c_shape
 from everywhereml.code_generators.jinja.filters.to_c_array import to_c_array
 from everywhereml.code_generators.jinja.filters.to_c_comment import to_c_comment
+from everywhereml.code_generators.jinja.filters.to_py_comment import to_py_comment
+from everywhereml.code_generators.jinja.filters.to_py_list import to_py_list
 from everywhereml.code_generators.jinja.filters.to_variable_name import to_variable_name
